@@ -15,6 +15,7 @@
 #include "globalcontactmodel.h"
 #include "kaddressbook_options.h"
 #include "kaddressbookadaptor.h"
+#include "kcmutils_version.h"
 #include "manageshowcollectionproperties.h"
 #include "modelcolumnmanager.h"
 #include "printing/printingwizard.h"
@@ -68,6 +69,8 @@
 #include <KContacts/ContactGroup>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
+#include <KPluginLoader>
+#include <KPluginMetaData>
 #include <KSelectionProxyModel>
 #include <KToggleAction>
 #include <KXMLGUIClient>
@@ -119,7 +122,7 @@ public:
 
         if (role == Qt::CheckStateRole) {
             // Don't show the checkbox if the collection can't contain incidences
-            const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid() && isStructuralCollection(collection)) {
                 return QVariant();
             }
@@ -267,7 +270,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
                     << Akonadi::StandardActionManager::SynchronizeResources << Akonadi::StandardActionManager::SynchronizeCollectionsRecursive
                     << Akonadi::StandardActionManager::MoveItemToMenu << Akonadi::StandardActionManager::CopyItemToMenu;
 
-    for (Akonadi::StandardActionManager::Type standardAction : qAsConst(standardActions)) {
+    for (Akonadi::StandardActionManager::Type standardAction : std::as_const(standardActions)) {
         mActionManager->createAction(standardAction);
     }
     guiClient->actionCollection()->setDefaultShortcut(mActionManager->action(Akonadi::StandardActionManager::DeleteItems), QKeySequence(Qt::Key_Delete));
@@ -275,7 +278,7 @@ MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     contactActions << Akonadi::StandardContactActionManager::CreateContact << Akonadi::StandardContactActionManager::CreateContactGroup
                    << Akonadi::StandardContactActionManager::EditItem;
 
-    for (Akonadi::StandardContactActionManager::Type contactAction : qAsConst(contactActions)) {
+    for (Akonadi::StandardContactActionManager::Type contactAction : std::as_const(contactActions)) {
         mActionManager->createAction(contactAction);
     }
 
@@ -332,16 +335,16 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
     }
 
     if (!importActions.isEmpty()) {
-        KActionMenu *importMenu = new KActionMenu(i18n("Import"), this);
+        auto importMenu = new KActionMenu(i18n("Import"), this);
         collection->addAction(QStringLiteral("import_menu"), importMenu);
-        for (QAction *act : qAsConst(importActions)) {
+        for (QAction *act : std::as_const(importActions)) {
             importMenu->addAction(act);
         }
     }
     if (!exportActions.isEmpty()) {
-        KActionMenu *exportMenu = new KActionMenu(i18n("Export"), this);
+        auto exportMenu = new KActionMenu(i18n("Export"), this);
         collection->addAction(QStringLiteral("export_menu"), exportMenu);
-        for (QAction *act : qAsConst(exportActions)) {
+        for (QAction *act : std::as_const(exportActions)) {
             exportMenu->addAction(act);
         }
     }
@@ -350,13 +353,14 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 void MainWidget::configure()
 {
     QPointer<KCMultiDialog> dlg = new KCMultiDialog(this);
-    dlg->addModule(QStringLiteral("akonadicontact_actions.desktop"));
-    dlg->addModule(QStringLiteral("kcmldap.desktop"));
-    dlg->addModule(QStringLiteral("kaddressbook_config_plugins.desktop"));
-#ifdef WITH_KUSERFEEDBACK
-    dlg->addModule(QStringLiteral("kaddressbook_config_userfeedback.desktop"));
+    const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/kaddressbook"));
+    for (const KPluginMetaData &metaData : availablePlugins) {
+#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+        dlg->addModule(metaData);
+#else
+        dlg->addModule(metaData.pluginId());
 #endif
-
+    }
     dlg->exec();
     delete dlg;
 }
@@ -371,7 +375,7 @@ void MainWidget::handleCommandLine(const QStringList &arguments)
         const QStringList lst = parser.positionalArguments();
         for (const QString &urlStr : lst) {
             const QUrl url(QUrl::fromUserInput(urlStr));
-            for (KAddressBookImportExport::PluginInterface *interface : qAsConst(mImportExportPluginInterfaceList)) {
+            for (KAddressBookImportExport::PluginInterface *interface : std::as_const(mImportExportPluginInterfaceList)) {
                 if (interface->canImportFileType(url)) {
                     interface->importFile(url);
                     break;
@@ -613,7 +617,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::grantleeThemeSelected, this, &MainWidget::slotGrantleeThemeSelected);
     connect(mGrantleeThemeManager, &GrantleeTheme::ThemeManager::updateThemes, this, &MainWidget::slotGrantleeThemesUpdated);
 
-    KActionMenu *themeMenu = new KActionMenu(i18n("&Themes"), this);
+    auto themeMenu = new KActionMenu(i18n("&Themes"), this);
     collection->addAction(QStringLiteral("theme_menu"), themeMenu);
 
     initGrantleeThemeName();
@@ -642,14 +646,14 @@ void MainWidget::setupActions(KActionCollection *collection)
     action->setWhatsThis(i18n("Select all contacts in the current address book view."));
     connect(action, &QAction::triggered, mItemView, &Akonadi::EntityTreeView::selectAll);
 
-    auto *qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
+    auto qrtoggleAction = collection->add<KToggleAction>(QStringLiteral("options_show_qrcodes"));
     qrtoggleAction->setText(i18n("Show QR Codes"));
     qrtoggleAction->setWhatsThis(i18n("Show QR Codes in the contact."));
     connect(qrtoggleAction, &KToggleAction::toggled, this, &MainWidget::setQRCodeShow);
 
     mViewModeGroup = new QActionGroup(this);
 
-    QAction *act = new QAction(i18nc("@action:inmenu", "Simple (one column)"), mViewModeGroup);
+    auto act = new QAction(i18nc("@action:inmenu", "Simple (one column)"), mViewModeGroup);
     act->setCheckable(true);
     act->setData(1);
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_1));
@@ -829,7 +833,7 @@ Akonadi::Collection MainWidget::currentAddressBook() const
 {
     if (mCollectionView->selectionModel() && mCollectionView->selectionModel()->hasSelection()) {
         const QModelIndex index = mCollectionView->selectionModel()->selectedIndexes().first();
-        const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         return collection;
     }
@@ -1017,7 +1021,7 @@ const Akonadi::Item::List MainWidget::collectSelectedAllContactsItem(QItemSelect
     for (int i = 0; i < indexes.count(); ++i) {
         const QModelIndex index = indexes.at(i);
         if (index.isValid()) {
-            const Akonadi::Item item = index.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+            const auto item = index.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
             if (item.isValid()) {
                 if (item.hasPayload<KContacts::Addressee>() || item.hasPayload<KContacts::ContactGroup>()) {
                     lst.append(item);
@@ -1041,7 +1045,7 @@ void MainWidget::slotServerSideSubscription()
 
 void MainWidget::slotCurrentCollectionChanged(const Akonadi::Collection &col)
 {
-    for (auto *interface : qAsConst(mImportExportPluginInterfaceList)) {
+    for (auto interface : std::as_const(mImportExportPluginInterfaceList)) {
         interface->setDefaultCollection(col);
     }
     bool isOnline;
