@@ -75,7 +75,7 @@ QString CompactStyle::contactsToHtml(const KContacts::Addressee::List &contacts)
     for (const KContacts::Addressee &contact : contacts) {
         // get the values
         QStringList values;
-        for (const ContactFields::Field &field : qAsConst(fields)) {
+        for (const ContactFields::Field &field : std::as_const(fields)) {
             // we need only values with content
             const QString value = ContactFields::value(field, contact).trimmed();
             if (!value.isEmpty()) {
